=====================================
Eupompos : Qt, C++/Python graph maker
=====================================
Eupompos by suizokukan (suizokukan AT orange DOT fr)

Note : this Python3 project can't be used with python2.

project's purpose
=================
Read a bunch of (c++/Python)Qt files and draw the connections.

installation
============
$pip3 install katal

name
====
The name Eupompos comes from the Ancient Greek Εὔπομπος, a famous painter.

more
====
see README.md file ("how to use" section)
see https://github.com/suizokukan/eupompos
